@@ -39,9 +39,11 @@ sld.plotnormals(xlim=[-0.2, 0.2], ylim=[-0.8, -0.4], zlim=[-0.2, 0.2], factor=0.
 acft.eulersolve(wakeiter=1)
 acft.forces_report()
 acft.stabreport()
-plot_Cps(sld, elems=[wng])
+'''plot_Cps(sld, elems=[wng])
 plot_Cls(sld, wings=[wng])
 plot_Cds(sld, wings=[wng])
 plot_Cms(sld, wings=[wng])
 plot_gammas(sld, wings=[wng])
-sld.plotgeometry(xlim=[-0.6, 0.6], ylim=[-0.6, 0.6], zlim=[-0.6, 0.6], velfield=False)
\ No newline at end of file
+sld.plotgeometry(xlim=[-0.6, 0.6], ylim=[-0.6, 0.6], zlim=[-0.6, 0.6], velfield=False)'''
+
+acft.design_derivatives()
\ No newline at end of file
